# BounceDesktop

BounceDesktop is a lightweight hardware-accelerated library for creating and interacting
with virtual desktops.

# Dependencies

poetry, libvncserver (optional), gmock, gtest, libgvnc (from gtk-vnc)
